@@ -53,13 +53,15 @@ class SecretKeyGenerator:
         """
 
         if len(secret_key_to_validate) != self._len_of_secret_key:
-            os.remove(self._file_name)
+            secret_key_file = open(self._file_name, 'w')
+            secret_key_file.write("")
+            secret_key_file.close()
             raise ValueError
 
     def _write_secret_key_to_file(self):
         """Writing the secret key to file"""
 
-        secret_key_file = open(self._file_name, 'x')
+        secret_key_file = open(self._file_name, 'w')
         secret_key_file.write(self._secret_key)
         secret_key_file.close()
 
